@@ -1,9 +1,9 @@
-/* Time-stamp: <2008-04-03 19:49:31 poser>
+/* Time-stamp: <2008-05-20 16:24:49 poser>
  *
  * Describes the content of a Unicode (UTF-8) text file by reporting
  * the character ranges to which different portions of the text belong.
  * 
- * Copyright (C) 2003-2007 William J. Poser (billposer@alum.mit.edu)
+ * Copyright (C) 2003-2008 William J. Poser (billposer@alum.mit.edu)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 the GNU General Public License
@@ -266,11 +266,11 @@ int main (int ac, char *av[])
       exit(2);
       break; 			/* NOTREACHED */
     case 'L':
-      ListRanges(stderr,1);
+      ListRanges(stdout,1);
       exit(2);
       break; 			/* NOTREACHED */
     case 'l':
-      ListRanges(stderr,0);
+      ListRanges(stdout,0);
       exit(2);
       break; 			/* NOTREACHED */
     case 'm':
